@@ -5,11 +5,21 @@
 	# create file to write. make directory if necessary.
 sub creat {
 	local($fnam) = @_;
-	local($dnam) = $fnam;
-	while ($dnam =~ s/\/[^\/]+$//) {
-		last if (-d $dnam);
-		mkdir($dnam, 0777) || &die("mkdir $dnam");
-	}
+	local($parent) = $fnam;
+	&mkdir($parent) if ($parent =~ s/\/[^\/]+$//);
 	open($fnam, ">$fnam") || &die("creat $fnam");
 	$fnam;
 }
+
+sub mkdir {
+	local($dnam) = @_;
+	return if (-d $dnam);
+	local($parent) = $dnam;
+	if ($parent =~ s/\/[^\/]+$//) {
+		&mkdir($parent);
+	} else {
+		return;
+	}
+	mkdir($dnam, 0777) || &die("mkdir $dnam");
+}
+
