@@ -9,6 +9,8 @@
 sub generateFileName {
 	# assumes ending with slash
 	local($pat) = $CONFIG{"basedir:"};
+	$pat =~ s/\/+$//;
+	$pat .= "/";
 	$pat .= $CONFIG{"cardpath:"};
 	$pat =~ s/%i/&gfn_initial/ge;
 	$pat =~ s/%y/&gfn_year/ge;
